@@ -57,8 +57,8 @@ class Changelog:
             or defaults.change_type_order
         )
         self.rev_range = args.get("rev_range")
-        self.tag_format = args.get("tag_format") or self.config.settings.get(
-            "tag_format"
+        self.tag_format: str = (
+            args.get("tag_format") or self.config.settings["tag_format"]
         )
         self.merge_prerelease = args.get(
             "merge_prerelease"
@@ -137,12 +137,9 @@ class Changelog:
         # Don't continue if no `file_name` specified.
         assert self.file_name
 
-        tags = git.get_tags()
-        if not tags:
-            tags = []
+        tags = changelog.get_version_tags(self.scheme, git.get_tags()) or []
 
         end_rev = ""
-
         if self.incremental:
             changelog_meta = changelog.get_metadata(self.file_name, self.scheme)
             latest_version = changelog_meta.get("latest_version")
