@@ -14,6 +14,7 @@ from commitizen.exceptions import (
     NoAnswersError,
     NoCommitBackupError,
     NotAGitProjectError,
+    NotAllowed,
     NothingToCommitError,
 )
 from commitizen.git import smart_open
@@ -63,10 +64,14 @@ class Commit:
 
     def __call__(self):
         dry_run: bool = self.arguments.get("dry_run")
+        write_message_to_file = self.arguments.get("write_message_to_file")
 
         if git.is_staging_clean() and not dry_run:
             raise NothingToCommitError("No files added to staging!")
 
+        if write_message_to_file is not None and write_message_to_file.is_dir():
+            raise NotAllowed(f"{write_message_to_file} is a directory")
+
         retry: bool = self.arguments.get("retry")
 
         if retry:
@@ -76,6 +81,10 @@ class Commit:
 
         out.info(f"\n{m}\n")
 
+        if write_message_to_file:
+            with smart_open(write_message_to_file, "w") as file:
+                file.write(m)
+
         if dry_run:
             raise DryRunExit()
 
